=======
History
=======

0.3.0 (2017-11-06)
------------------

* Add option to choose if a parameters must be mandatory

0.2.0 (2017-10-31)
------------------

* Add suport to upload and configure files and reports to JasperServer using a yml file

0.1.0 (2017-07-30)
------------------

* First release on PyPI.
